@@ -1,18 +1,55 @@
-#[doc = "Reader of register NCR"]
-pub type R = crate::R<u32, super::NCR>;
-#[doc = "Writer for register NCR"]
-pub type W = crate::W<u32, super::NCR>;
-#[doc = "Register NCR `reset()`'s with value 0"]
-impl crate::ResetValue for super::NCR {
-    type Type = u32;
+#[doc = "Register `NCR` reader"]
+pub struct R(crate::R<NCR_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<NCR_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
-#[doc = "Reader of field `LBL`"]
-pub type LBL_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `LBL`"]
+impl From<crate::R<NCR_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<NCR_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `NCR` writer"]
+pub struct W(crate::W<NCR_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<NCR_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<NCR_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<NCR_SPEC>) -> Self {
+        W(writer)
+    }
+}
+#[doc = "Field `LBL` reader - Loop Back Local"]
+pub struct LBL_R(crate::FieldReader<bool, bool>);
+impl LBL_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        LBL_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for LBL_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LBL` writer - Loop Back Local"]
 pub struct LBL_W<'a> {
     w: &'a mut W,
 }
@@ -30,13 +67,26 @@ impl<'a> LBL_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
-#[doc = "Reader of field `RXEN`"]
-pub type RXEN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `RXEN`"]
+#[doc = "Field `RXEN` reader - Receive Enable"]
+pub struct RXEN_R(crate::FieldReader<bool, bool>);
+impl RXEN_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        RXEN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for RXEN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `RXEN` writer - Receive Enable"]
 pub struct RXEN_W<'a> {
     w: &'a mut W,
 }
@@ -54,13 +104,26 @@ impl<'a> RXEN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
-#[doc = "Reader of field `TXEN`"]
-pub type TXEN_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TXEN`"]
+#[doc = "Field `TXEN` reader - Transmit Enable"]
+pub struct TXEN_R(crate::FieldReader<bool, bool>);
+impl TXEN_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TXEN_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TXEN_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TXEN` writer - Transmit Enable"]
 pub struct TXEN_W<'a> {
     w: &'a mut W,
 }
@@ -78,13 +141,26 @@ impl<'a> TXEN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
-#[doc = "Reader of field `MPE`"]
-pub type MPE_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `MPE`"]
+#[doc = "Field `MPE` reader - Management Port Enable"]
+pub struct MPE_R(crate::FieldReader<bool, bool>);
+impl MPE_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        MPE_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for MPE_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `MPE` writer - Management Port Enable"]
 pub struct MPE_W<'a> {
     w: &'a mut W,
 }
@@ -102,13 +178,26 @@ impl<'a> MPE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
-#[doc = "Reader of field `CLRSTAT`"]
-pub type CLRSTAT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `CLRSTAT`"]
+#[doc = "Field `CLRSTAT` reader - Clear Statistics Registers"]
+pub struct CLRSTAT_R(crate::FieldReader<bool, bool>);
+impl CLRSTAT_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        CLRSTAT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for CLRSTAT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CLRSTAT` writer - Clear Statistics Registers"]
 pub struct CLRSTAT_W<'a> {
     w: &'a mut W,
 }
@@ -126,13 +215,26 @@ impl<'a> CLRSTAT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
-#[doc = "Reader of field `INCSTAT`"]
-pub type INCSTAT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `INCSTAT`"]
+#[doc = "Field `INCSTAT` reader - Increment Statistics Registers"]
+pub struct INCSTAT_R(crate::FieldReader<bool, bool>);
+impl INCSTAT_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        INCSTAT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for INCSTAT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `INCSTAT` writer - Increment Statistics Registers"]
 pub struct INCSTAT_W<'a> {
     w: &'a mut W,
 }
@@ -150,13 +252,26 @@ impl<'a> INCSTAT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
-#[doc = "Reader of field `WESTAT`"]
-pub type WESTAT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `WESTAT`"]
+#[doc = "Field `WESTAT` reader - Write Enable for Statistics Registers"]
+pub struct WESTAT_R(crate::FieldReader<bool, bool>);
+impl WESTAT_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        WESTAT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for WESTAT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `WESTAT` writer - Write Enable for Statistics Registers"]
 pub struct WESTAT_W<'a> {
     w: &'a mut W,
 }
@@ -174,13 +289,26 @@ impl<'a> WESTAT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
-#[doc = "Reader of field `BP`"]
-pub type BP_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `BP`"]
+#[doc = "Field `BP` reader - Back pressure"]
+pub struct BP_R(crate::FieldReader<bool, bool>);
+impl BP_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        BP_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for BP_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `BP` writer - Back pressure"]
 pub struct BP_W<'a> {
     w: &'a mut W,
 }
@@ -198,13 +326,26 @@ impl<'a> BP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
-#[doc = "Reader of field `TSTART`"]
-pub type TSTART_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TSTART`"]
+#[doc = "Field `TSTART` reader - Start Transmission"]
+pub struct TSTART_R(crate::FieldReader<bool, bool>);
+impl TSTART_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TSTART_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TSTART_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TSTART` writer - Start Transmission"]
 pub struct TSTART_W<'a> {
     w: &'a mut W,
 }
@@ -222,13 +363,26 @@ impl<'a> TSTART_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
-#[doc = "Reader of field `THALT`"]
-pub type THALT_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `THALT`"]
+#[doc = "Field `THALT` reader - Transmit Halt"]
+pub struct THALT_R(crate::FieldReader<bool, bool>);
+impl THALT_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        THALT_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for THALT_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `THALT` writer - Transmit Halt"]
 pub struct THALT_W<'a> {
     w: &'a mut W,
 }
@@ -246,13 +400,26 @@ impl<'a> THALT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 10)) | (((value as u32) & 0x01) << 10);
+        self.w.bits = (self.w.bits & !(0x01 << 10)) | ((value as u32 & 0x01) << 10);
         self.w
     }
 }
-#[doc = "Reader of field `TXPF`"]
-pub type TXPF_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TXPF`"]
+#[doc = "Field `TXPF` reader - Transmit Pause Frame"]
+pub struct TXPF_R(crate::FieldReader<bool, bool>);
+impl TXPF_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TXPF_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TXPF_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TXPF` writer - Transmit Pause Frame"]
 pub struct TXPF_W<'a> {
     w: &'a mut W,
 }
@@ -270,13 +437,26 @@ impl<'a> TXPF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 11)) | (((value as u32) & 0x01) << 11);
+        self.w.bits = (self.w.bits & !(0x01 << 11)) | ((value as u32 & 0x01) << 11);
         self.w
     }
 }
-#[doc = "Reader of field `TXZQPF`"]
-pub type TXZQPF_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TXZQPF`"]
+#[doc = "Field `TXZQPF` reader - Transmit Zero Quantum Pause Frame"]
+pub struct TXZQPF_R(crate::FieldReader<bool, bool>);
+impl TXZQPF_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TXZQPF_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TXZQPF_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TXZQPF` writer - Transmit Zero Quantum Pause Frame"]
 pub struct TXZQPF_W<'a> {
     w: &'a mut W,
 }
@@ -294,13 +474,26 @@ impl<'a> TXZQPF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 12)) | (((value as u32) & 0x01) << 12);
+        self.w.bits = (self.w.bits & !(0x01 << 12)) | ((value as u32 & 0x01) << 12);
         self.w
     }
 }
-#[doc = "Reader of field `SRTSM`"]
-pub type SRTSM_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `SRTSM`"]
+#[doc = "Field `SRTSM` reader - Store Receive Time Stamp to Memory"]
+pub struct SRTSM_R(crate::FieldReader<bool, bool>);
+impl SRTSM_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        SRTSM_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for SRTSM_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `SRTSM` writer - Store Receive Time Stamp to Memory"]
 pub struct SRTSM_W<'a> {
     w: &'a mut W,
 }
@@ -318,13 +511,26 @@ impl<'a> SRTSM_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 15)) | (((value as u32) & 0x01) << 15);
+        self.w.bits = (self.w.bits & !(0x01 << 15)) | ((value as u32 & 0x01) << 15);
         self.w
     }
 }
-#[doc = "Reader of field `ENPBPR`"]
-pub type ENPBPR_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `ENPBPR`"]
+#[doc = "Field `ENPBPR` reader - Enable PFC Priority-based Pause Reception"]
+pub struct ENPBPR_R(crate::FieldReader<bool, bool>);
+impl ENPBPR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        ENPBPR_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for ENPBPR_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ENPBPR` writer - Enable PFC Priority-based Pause Reception"]
 pub struct ENPBPR_W<'a> {
     w: &'a mut W,
 }
@@ -342,13 +548,26 @@ impl<'a> ENPBPR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 16)) | (((value as u32) & 0x01) << 16);
+        self.w.bits = (self.w.bits & !(0x01 << 16)) | ((value as u32 & 0x01) << 16);
         self.w
     }
 }
-#[doc = "Reader of field `TXPBPF`"]
-pub type TXPBPF_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `TXPBPF`"]
+#[doc = "Field `TXPBPF` reader - Transmit PFC Priority-based Pause Frame"]
+pub struct TXPBPF_R(crate::FieldReader<bool, bool>);
+impl TXPBPF_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TXPBPF_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for TXPBPF_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `TXPBPF` writer - Transmit PFC Priority-based Pause Frame"]
 pub struct TXPBPF_W<'a> {
     w: &'a mut W,
 }
@@ -366,13 +585,26 @@ impl<'a> TXPBPF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
-#[doc = "Reader of field `FNP`"]
-pub type FNP_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `FNP`"]
+#[doc = "Field `FNP` reader - Flush Next Packet"]
+pub struct FNP_R(crate::FieldReader<bool, bool>);
+impl FNP_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        FNP_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for FNP_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `FNP` writer - Flush Next Packet"]
 pub struct FNP_W<'a> {
     w: &'a mut W,
 }
@@ -390,13 +622,26 @@ impl<'a> FNP_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
-#[doc = "Reader of field `LPI`"]
-pub type LPI_R = crate::R<bool, bool>;
-#[doc = "Write proxy for field `LPI`"]
+#[doc = "Field `LPI` reader - Low Power Idle Enable"]
+pub struct LPI_R(crate::FieldReader<bool, bool>);
+impl LPI_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        LPI_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for LPI_R {
+    type Target = crate::FieldReader<bool, bool>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `LPI` writer - Low Power Idle Enable"]
 pub struct LPI_W<'a> {
     w: &'a mut W,
 }
@@ -414,7 +659,7 @@ impl<'a> LPI_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
@@ -591,4 +836,30 @@ impl W {
     pub fn lpi(&mut self) -> LPI_W {
         LPI_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Network Control Register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ncr](index.html) module"]
+pub struct NCR_SPEC;
+impl crate::RegisterSpec for NCR_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [ncr::R](R) reader structure"]
+impl crate::Readable for NCR_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [ncr::W](W) writer structure"]
+impl crate::Writable for NCR_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets NCR to value 0"]
+impl crate::Resettable for NCR_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
